@@ -2,7 +2,7 @@
 
 import sys
 import argparse
-import intercaat_functions as icaat
+import Intercaat.intercaat_functions as icaat
 import subprocess 
 
 def setup():
@@ -11,8 +11,8 @@ def setup():
     source_path = Path(__file__).resolve()
     source_dir = source_path.parent
     print(source_dir)
-    # command = "curl www.qhull.org/download/qhull-2020-src-8.0.2.tgz --output qhull-2020-src-8.0.2.tgz && tar -xvf qhull-2020-src-8.0.2.tgz && cd qhull-2020.2 &&  make &&  export LD_LIBRARY_PATH=$PWD/lib:$LD_LIBRARY_PATH &&  make install && cp bin/qvoronoi ../Intercaat/qhull/bin && cd .. && rm -r qhull-2020.2"
-    # process = subprocess.run(command, shell=True)
+    command = f" curl www.qhull.org/download/qhull-2020-src-8.0.2.tgz --output qhull-2020-src-8.0.2.tgz && tar -xvf qhull-2020-src-8.0.2.tgz && cd qhull-2020.2 &&  make &&  export LD_LIBRARY_PATH=$PWD/lib:$LD_LIBRARY_PATH &&  make install && cp bin/qvoronoi {source_dir}/qhull/bin && cd .. && rm -r qhull-2020.2"
+    process = subprocess.run(command, shell=True)
     return
 
 def main():
